==> aria2-1.9.3.tar.bz2: aria2-1.9.3/src/DHTQueryMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_QUERY_MESSAGE_H_
#define _D_DHT_QUERY_MESSAGE_H_

#include "DHTAbstractMessage.h"
#include "A2STR.h"

namespace aria2 {

class DHTQueryMessage:public DHTAbstractMessage {
protected:
  virtual std::string toStringOptional() const { return A2STR::NIL; }
public:
  DHTQueryMessage(const SharedHandle<DHTNode>& localNode,
                  const SharedHandle<DHTNode>& remoteNode,
                  const std::string& transactionID = A2STR::NIL);

  virtual ~DHTQueryMessage();

  virtual std::string getType() const;

  virtual void fillMessage(BDE& msgDict);

  virtual BDE getArgument() = 0;
  
  virtual bool isReply() const;

  virtual std::string toString() const;

  static const std::string Q;

  static const std::string A;
};

} // namespace aria2

#endif // _D_DHT_QUERY_MESSAGE_H_

==> aria2-1.10.9.tar.bz2: aria2-1.10.9/src/DHTQueryMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DHT_QUERY_MESSAGE_H
#define D_DHT_QUERY_MESSAGE_H

#include "DHTAbstractMessage.h"
#include "A2STR.h"
#include "ValueBase.h"

namespace aria2 {

class DHTQueryMessage:public DHTAbstractMessage {
protected:
  virtual std::string toStringOptional() const { return A2STR::NIL; }
public:
  DHTQueryMessage(const SharedHandle<DHTNode>& localNode,
                  const SharedHandle<DHTNode>& remoteNode,
                  const std::string& transactionID = A2STR::NIL);

  virtual ~DHTQueryMessage();

  virtual const std::string& getType() const;

  virtual void fillMessage(Dict* msgDict);

  virtual SharedHandle<Dict> getArgument() = 0;
  
  virtual bool isReply() const;

  virtual std::string toString() const;

  static const std::string Q;

  static const std::string A;
};

} // namespace aria2

#endif // D_DHT_QUERY_MESSAGE_H
